# Snapshot report for `test/js/errorTest.js`

The actual snapshot is saved in `errorTest.js.snap`.

Generated by [AVA](https://ava.li).

## structure

> Snapshot 1

    ServiceReply {
      error: Error {
        message: 'error message',
        stack: 'error stack',
        title: 'error title',
      },
    }
